function res = precision_multiply(args)
% This function returns the product of two arguments val1 and val2
    res = args.val1 * args.val2;

end %function
